@@ -19,6 +19,7 @@ class CacheControlMiddleware(BaseHTTPMiddleware):
         self,
         app: ASGIApp,
         cachecontrol: Optional[str] = None,
+        cachecontrol_max_http_code: Optional[int] = 500,
         exclude_path: Optional[Set[str]] = None,
     ) -> None:
         """Init Middleware.
@@ -31,6 +32,7 @@ class CacheControlMiddleware(BaseHTTPMiddleware):
         """
         super().__init__(app)
         self.cachecontrol = cachecontrol
+        self.cachecontrol_max_http_code = cachecontrol_max_http_code
         self.exclude_path = exclude_path or set()
 
     async def dispatch(self, request: Request, call_next):
@@ -41,7 +43,10 @@ class CacheControlMiddleware(BaseHTTPMiddleware):
                 if re.match(path, request.url.path):
                     return response
 
-            if request.method in ["HEAD", "GET"] and response.status_code < 500:
+            if (
+                request.method in ["HEAD", "GET"]
+                and response.status_code < self.cachecontrol_max_http_code
+            ):
                 response.headers["Cache-Control"] = self.cachecontrol
 
         return response
@@ -67,7 +72,10 @@ class LoggerMiddleware(BaseHTTPMiddleware):
     """MiddleWare to add logging."""
 
     def __init__(
-        self, app: ASGIApp, querystrings: bool = False, headers: bool = False,
+        self,
+        app: ASGIApp,
+        querystrings: bool = False,
+        headers: bool = False,
     ) -> None:
         """Init Middleware."""
         super().__init__(app)
@@ -101,8 +109,8 @@ class LowerCaseQueryStringMiddleware(BaseHTTPMiddleware):
         self.DECODE_FORMAT = "latin-1"
 
         query_string = ""
-        for k in request.query_params:
-            query_string += k.lower() + "=" + request.query_params[k] + "&"
+        for k, v in request.query_params.multi_items():
+            query_string += k.lower() + "=" + v + "&"
 
         query_string = query_string[:-1]
         request.scope["query_string"] = query_string.encode(self.DECODE_FORMAT)
